@@ -6,7 +6,7 @@ ICLUST.cluster <- function (r.mat,ICLUST.options) {#should allow for raw data, c
 #          reverse score items if negative correlations
 #          stop clustering if beta for new clusters < beta.min
 #          output =1 (short)    2  (show steps)     3 show rejects as we go
-
+#          
 #initialize  various arrays and get ready for the first pass
 output <- ICLUST.options$output
 num.var <- nrow(r.mat)
@@ -19,6 +19,11 @@ rownames(results) <- paste("C",1:(num.var-1),sep="")
 clusters <- diag(1,nrow =nrow(r.mat))    #original cluster structure is 1 item clusters
 rownames(clusters) <- rownames(r.mat)
 colnames(clusters) <- paste("V",1:num.var,sep="")
+diag(r.mat) <- 0
+row.range <- apply(r.mat,1,range,na.rm=TRUE)     
+item.max<- pmax(abs(row.range[1,]),abs(row.range[2,]))  #find the largest absolute similarity
+diag(r.mat) <- 1
+
 count=1
 
 #master loop 
@@ -37,15 +42,22 @@ if (ICLUST.options$correct) {   #find the largest and smallest similarities for
 	row.max <- pmax(abs(row.range[1,]),abs(row.range[2,]))  #find the largest absolute similarity
    } else {row.max <- rep(1, nrow(sim.mat)) }         #don't correct for largest similarity
    
-   item.rel <-  cluster.stats$alpha
+item.rel <- cluster.stats$alpha  
 for (i in 1: length(item.rel)) { if (cluster.stats$size[i]<2) {
 	item.rel[i] <- row.max[i]
 	#figure out item betas here?
 	}}
+	
+	
+if(output>3)  print(sim.mat)
+
 sq.max <- diag(1/sqrt(item.rel))     #used to correct for reliabilities
  #this is the corrected for maximum r similarities
 if (ICLUST.options$correct) {sim <- sq.max %*% sim.mat %*% sq.max   #this corrects for reliabilities but messes up the correlations of two item clusters with items
      } else {sim <- sim.mat}
+     
+
+
 diag(sim) <- NA                  #we need to not consider the diagonal when looking for maxima
 #find the most similar pair    and apply tests if we should combine
 test.alpha <- FALSE
@@ -71,14 +83,17 @@ max.row <- max.cell - (max.col-1)*nrow(sim) #need to fix the case of first colum
 if (max.row < 1) {max.row <- nrow(sim)
  max.col <- max.col-1 }
 
-#combine these two rows if the various criterion are passed
-beta.combined <-  2* sign.max*sim.mat[max.cell]/(1+sign.max* sim.mat[max.cell])   #unweighted beta
+
+
 
 size1 <- cluster.stats$size[max.row]
 if(size1 < 2) {V1 <- 1
 	beta1 <-  item.rel[max.row]
-	alpha1 <-  item.rel[max.row]
-	rbar1 <- item.rel[max.row] } else {
+	alpha1 <- item.rel[max.row]
+	rbar1 <-  item.rel[max.row]
+	
+    
+	} else {
 	rbar1 <- results[cluster.names[max.row],"rbar"]
 	beta1 <- results[cluster.names[max.row],"beta"]
 	alpha1 <- results[cluster.names[max.row],"alpha"]
@@ -88,40 +103,67 @@ if(size1 < 2) {V1 <- 1
 size2 <- cluster.stats$size[max.col]
 if(size2 < 2) {V2 <- 1 
 	beta2 <-  item.rel[max.col] 
-	alpha2 <-  item.rel[max.col] 
-	rbar2 <- item.rel[max.col] } else {
+	alpha2 <- item.rel[max.col] 
+	rbar2 <-  item.rel[max.col]
+	
+	
+	} else {
 	
 	rbar2 <- results[cluster.names[max.col],"rbar"]
 	beta2 <- results[cluster.names[max.col],"beta"]
 	alpha2 <- results[cluster.names[max.col],"alpha"] 
 	V2 <- size2 + size2 * (size2-1) * rbar2}
 
- 	
-Cov12 <- sign.max* sim.mat[max.cell] * sqrt(V1*V2) 
+
+
+
+Cov12 <- sign.max * sim.mat[max.cell] * sqrt(V1*V2) 
+r12 <- Cov12/(size1*size2)   #average between cluster r
 V12 <- V1 + V2 + 2 * Cov12
+
 size12 <- size1 + size2
-alpha <- (V12 - size12)*(size12/(size12-1))/V12
-rbar <- alpha/(size12-alpha*(size12-1))
+V12c <- (V12 - size12)*(size12/(size12-1))  #true variance
+rbar <- V12c/(size12^2)
+alpha <- V12c/V12
+
+
+#combine these two rows if the various criterion are passed
+beta.weighted <- size12^2 * sign.max *r12/V12
+beta.unweighted <-  2* sign.max*sim.mat[max.cell]/(1+sign.max* sim.mat[max.cell])
+if(ICLUST.options$weighted) {beta.combined <- beta.weighted} else {beta.combined <- beta.unweighted}  
+
+
 
 #what is the correlation of this new cluster with the two subclusters?
 #this considers item overlap problems
-c1 <-  sign.max*rbar1*size1*size1 + sign.max* Cov12  #corrects for item overlap
-c2 <-  rbar2*size2*size2 + Cov12    #only flip one of the two correlations with the combined cluster
+#There are actually two alternative solutions
+#a) (cor.gen=TRUE)   finds the correlation due to a shared general factor 
+#b) (cor.gen=FALSE)  finds the correlation for the general + group but remove the item overlap problem
+#neither seems optimal, in that a) will correctly identify non-correlated clusters, but b) is less affected by small clusters.
 
-if((size1<2) & (size2  <2)) {
+if(ICLUST.options$cor.gen) {
+c1 <-  r12 * size1 * size1 +  sign.max * Cov12  #corrected covariance?
+c2 <-  r12 * size2 * size2 +   Cov12 } else {
+c1 <-  size1^2* rbar1 +  sign.max * Cov12  #corrected covariance?
+c2 <-  size2^2 *rbar2 +   Cov12 }
+
+
+if((size1 < 2) && (size2  < 2)) {
        r1 <- sqrt(abs(rbar1))   #this  corrects for reliability in a two item cluster
        r2 <- sign.max* r1         #flips the sign if two are negatively correlated 
                              } else {    #this next part corrects for item overlap as well as reliability of the subcluster
-                                         #is the default option
-                                 if (ICLUST.options$correct.cluster) {
-                                 if(size1 > size2) {r1 <- c1/sqrt((V1-size1+size1*rbar1)*V12)
-												    if (size2<2) {r2 <- sign.max* c2/sqrt(abs(rbar1)*V12)} else { r2 <- sign.max* c2/sqrt((V2-size2+size2*rbar2)*V12)}
+                                        
+                                 if (ICLUST.options$correct.cluster) {   #correct is the default option
+                                 if(size1 > size2)  {r1 <- c1/sqrt((V1 - size1  +size1 * rbar1) * V12) 
+												       if (size2 < 2)  {r2 <- sign.max * c2/sqrt(abs(rbar2)*V12)}  else  { r2 <- sign.max * c2/sqrt((V2-size2 + size2 * rbar2)*V12c)}
 												    } else {
-												       if(size1<2){ r1 <-sign.max* c1/sqrt(abs(rbar1)*V12)} else { r1 <-sign.max* c1/sqrt((V1-size1+size1*rbar1)*V12)  }  
+												      if(size1 < 2 )   {r1 <- sign.max * c1/sqrt(abs(rbar1)*V12)} else  {  r1 <- sign.max * c1/sqrt((V1-size1 + size1 * rbar1)*V12c)  }  
                                      #flip the smaller of the two clusters
-												            r2 <-  c2/sqrt((V2-size2+size2*rbar2)*V12) }
+                                                         if (size2 < 2) {r2 <- sign.max* c2/sqrt(abs(rbar2)*V12)} else { r2 <- sign.max* c2/sqrt((V2-size2 + size2*rbar2)*V12c)}
+												          #  r2 <-  c2/sqrt((V2-size2+size2*rbar2)*V12c) 
+												          }
 							         
-							} else {if(size1 > size2) {r1 <- c1/sqrt(V1*V12)
+							} else {if(size1 > size2) {r1 <- c1/sqrt(V1*V12)   #do not correct
 												   r2 <- sign.max* c2/sqrt(V2*V12)
 												    } else {
 												        r1 <-sign.max* c1/sqrt(V1*V12)  } 
@@ -185,7 +227,7 @@ if(test.beta & test.alpha) { break} else { #we have failed the combining criteri
 			
 			sim[max.row,max.col] <- NA 
 		sim[max.col,max.row] <- NA }}
-    }   #end of test.beta&test.alpha
+    }   #end of test.beta & test.alpha
     
 }    #end of while test.alpha & test.beta.loop
 
@@ -224,7 +266,7 @@ results[count,3:18] <- round(results[count,3:18],ICLUST.options$digits)
 cluster.names[max.row] <- paste("C",count,sep="")
 colnames(clusters) <- cluster.names
 clusters <- clusters[,-max.col]
-cluster.names<- colnames(clusters)
+cluster.names <- colnames(clusters)
 
 #row.max <- row.max[-max.col]    
 
@@ -241,4 +283,6 @@ if(num.var - count < 1) {keep.clustering <- FALSE}   #only one cluster left
 
 ICLUST.cluster <- list(results=results,clusters=clusters,number <- num.var - count)
 }   # end ICLUST.cluster
-#modified June 12, 2008 to  calculate the item-cluster correlation for cluster of size 2
\ No newline at end of file
+#modified June 12, 2008 to  calculate the item-cluster correlation for cluster of size 2
+#modified June 14, 2009 to find weighted or unweighted beta
+#unweighted had been the default option before but it would seem that weighted makes more sense
\ No newline at end of file
